@@ -17,7 +17,7 @@ use XML::LibXML::Literal;
 use XML::LibXML::Number;
 
 use vars qw($VERSION);
-$VERSION = "2.0002"; # VERSION TEMPLATE: DO NOT CHANGE
+$VERSION = "2.0003"; # VERSION TEMPLATE: DO NOT CHANGE
 
 use overload 
         '""' => \&to_literal,
@@ -83,7 +83,11 @@ sub get_node {
     $self->[$pos - 1];
 }
 
-*item = \&get_node;
+sub item
+{
+    my ($self, $pos) = @_;
+    return $self->[$pos];
+}
 
 sub get_nodelist {
     my $self = CORE::shift;
